@@ -17,7 +17,6 @@ from sklearn.preprocessing import StandardScaler
 from sklearn import linear_model
 from sklearn.model_selection import cross_val_score, cross_val_predict
 import joblib
-from sklearn.linear_model import ElasticNet
 from sklearn.ensemble import RandomForestRegressor
 from sklearn.model_selection import GridSearchCV
 import sys
@@ -32,12 +31,6 @@ from sklearn.decomposition import PCA
 from sklearn.feature_selection import mutual_info_classif
 import folium
 import leafmap.foliumap as leafmap
-from IPython.display import display
-from sklearn import metrics
-from sklearn.preprocessing import StandardScaler
-from sklearn.cluster import DBSCAN
-from kneed import KneeLocator
-from sklearn.neighbors import NearestNeighbors
 import matplotlib.animation as animation
 
 
@@ -887,7 +880,7 @@ def Error_AVM_vs_ML(reml2): ### MOD X TENER RL Y ENET
                                    '%_XGB_Acumulado': [],'Cantidad_XGB': []});
 
     col = ['Intervalo','%_RF_Acumulado','Cantidad_RF', "%_XGB_Acumulado",'Cantidad_XGB'];
-    cant=[0,0,0]
+    cant=[0,0]
     k=[5,10,15,20,25,50]
     for lim in range(0,len(k)):
         if k[lim]==5:
@@ -904,6 +897,17 @@ def Error_AVM_vs_ML(reml2): ### MOD X TENER RL Y ENET
         tablaux = pd.DataFrame([[inter,porcentaje3,cantidad3,porcentaje4,cantidad4]],
                                 columns=col);
         tabla=pd.concat([tabla, tablaux],ignore_index=True);
+    inter=f"|Error|>50%"
+    porcentaje3=100*(reml2.shape[0]-cant[0])/reml2.shape[0]+porcentaje3
+    cantidad3=reml2.shape[0]-cant[0]
+    porcentaje4=100*(reml2.shape[0]-cant[1])/reml2.shape[0]+porcentaje4
+    cantidad4=reml2.shape[0]-cant[1]
+    cant=[cant[0]+cantidad3,cant[1]+cantidad4]
+
+
+    tablaux = pd.DataFrame([[inter,porcentaje3,cantidad3,porcentaje4,cantidad4]],
+                            columns=col);
+    tabla=pd.concat([tabla, tablaux],ignore_index=True);
     return tabla
 
 def Tabla_Estadistica_Error2(df): ## MOD X TENER RL Y ENET ##
